@@ -102,12 +102,19 @@ else:
                     callback(response.body)
                 elif 404 == response.code:
                     callback(None)
-                raise Exception(response.error)
+                else:
+                    raise Exception(response.error)
 
             self.client.fetch(self.url % key, method="GET", callback=_callback)
 
         def put(self, key, value, callback=None):
-            self.client.fetch(self.url % key, method="PUT", body=value, callback=callback)
+            def _callback(response):
+                if 200 == response.code:
+                    callback()
+                else:
+                    raise Exception(response.error)
+
+            self.client.fetch(self.url % key, method="PUT", body=value, callback=_callback)
 
         def get_multiple(self, keys, callback=None):
             def _callback(response):
@@ -128,7 +135,13 @@ else:
             self.get_multiple(keys, _callback)
 
         def put_multiple(self, mapping, callback=None):
-            self.client.fetch(self.root_url, method="PUT", body=json.dumps(mapping), callback=callback)
+            def _callback(response):
+                if 200 == response.code:
+                    callback()
+                else:
+                    raise Exception(response.error)
+
+            self.client.fetch(self.root_url, method="PUT", body=json.dumps(mapping), callback=_callback)
 
 # endregion
 
